package com.biganto.visual.roompark.data.repository.mapper

import android.content.res.Resources
import com.biganto.visual.roompark.data.repository.api.retrofit.raw.*
import com.biganto.visual.roompark.data.repository.db.requrey.TitledPhoto
import com.biganto.visual.roompark.data.repository.db.requrey.model.ArticleEntity
import com.biganto.visual.roompark.data.repository.db.requrey.model.FeedEntity
import com.biganto.visual.roompark.data.repository.db.requrey.model.ImageAlbumEntity
import com.biganto.visual.roompark.data.repository.db.requrey.model.UserEntity
import kotlin.math.max

/**
 * Created by Vladislav Bogdashkin on 06.11.2019.
 */

private val display = Resources.getSystem().displayMetrics

fun fromRaw(raw: AuthRaw) : UserEntity {
    val user = UserEntity()
    user.setEmail(raw.email)
    user.setUuid(raw.id)
    user.setAuthToken(raw.token)
    user.setName(raw.name)
    user.setTargetResolution(calcTargetResolution)
    return user
}

fun fromRaw(raw:FeedRaw) : FeedEntity {
    val entity  = FeedEntity()
    entity.setTitle(raw.title)
    entity.setAlias(raw.alias)
    return entity
}

fun fromRaw(raw:ArticleRaw) : ArticleEntity {
    val entity  = ArticleEntity()
    entity.setId(raw.id)
    entity.setPublished(raw.published)
    entity.setTitle(raw.title)
    entity.setBody(raw.body)
    entity.setAnnounce(raw.announce)
    entity.setPreview(raw.preview)
    raw.photo?.let {entity.photo = fromRawList(it, ::fromRaw)}
    val feed = FeedEntity()
    feed.setAlias(raw.feed_alias)
    entity.setFeed(feed)

    return entity
}


fun fromRaw(raw:NewsArticleRaw,feedAlias:String):ArticleEntity{
    val entity = ArticleEntity()
    entity.setId(raw.id)
    entity.setPreview(raw.preview)
    entity.setAnnounce(raw.announce)
    entity.setPublished(raw.published)
    entity.setTitle(raw.title)
    val feed = FeedEntity()
    feed.setAlias(feedAlias)
    entity.setFeed(feed)
    return entity
}


fun fromRaw(raw:NewsPhotoRaw):TitledPhoto{
    return TitledPhoto(raw.title,raw.url)
}


fun fromRaw(raw:ImageAlbumRaw) : ImageAlbumEntity {
    val entity  = ImageAlbumEntity()
    entity.setId(raw.id)
    entity.setTitle(raw.title)
    entity.setPublished(raw.date)
    entity.setSort(raw.sort)
    return entity
}

//fun fromRaw(raw: List<FeedRaw>):List<FeedEntity> = List(raw.size) { index-> fromRaw(raw[index]) }


fun <E,M> fromRawList(raw: List<E>,block:(E)->M):List<M> = List(raw.size) { index-> block(raw[index]) }

fun fromRaw(raw: List<NewsArticleRaw>,feedAlias:String):List<ArticleEntity> =
    List(raw.size) { index-> fromRaw(raw[index],feedAlias) }

val calcTargetResolution = max(display.widthPixels,display.heightPixels)
